# Route Similarity

Library of python methods to compute similarity between two routes described using lat, lon coordinates

### Installation

```sh
pip install routesimilarity
```

For development environments...

```sh
git clone git@github.com:shkr/routesimilarity.git
cd routesimilarity/
python setup.py develop
```

### Development

Want to contribute? Submit a PR.

### Todos
 - Only directed_hausdorff based on geodesic distance metric available now. Needs more similarity functions..
 - Add Example problems

